==> nmfprofiler-0.2.1.tar.gz: nmfprofiler-0.2.1/tests/test_nmfprofiler.py <==
from nmfprofiler.nmfprofiler import NMFProfiler  # type: ignore
import numpy as np

# Generate a small example to decompose
# Groups
y = np.array([1, 1, 1, 1, 1, 0, 0, 0, 0, 0])

# Omic1
omic1 = np.array(
    [
        [
            2.278,
            3.55,
            2.38,
            2.289,
            2.3,
            2.364,
            1.562,
            1.533,
            1.434,
            2.095,
            0.427,
            0.113,
            0.278,
            0.212,
            0.306,
            0.379,
            0.375,
            0.056,
            0.219,
            0.227,
            0.148,
            0.101,
            0.166,
            0.039,
            0.046,
            0.161,
            0.163,
            0.066,
            0.012,
            0.13,
            0.169,
            0.209,
            0.207,
            0.257,
            0.078,
            0.111,
            0.064,
            0.187,
            0.159,
            0.338,
        ],
        [
            2.048,
            2.438,
            2.048,
            2.257,
            1.888,
            1.398,
            1.178,
            0.891,
            0.749,
            1.204,
            0.043,
            0.095,
            0.126,
            0.02,
            0.29,
            0.242,
            0.438,
            0.403,
            0.359,
            0.152,
            0.256,
            0.444,
            0.643,
            0.863,
            0.396,
            0.619,
            0.765,
            0.338,
            0.95,
            0.218,
            0.121,
            0.166,
            0.074,
            0.08,
            0.159,
            0.195,
            0.077,
            0.051,
            0.096,
            0.074,
        ],
        [
            1.122,
            1.31,
            1.013,
            1.645,
            0.675,
            1.187,
            0.672,
            0.894,
            0.604,
            1.362,
            0.464,
            0.109,
            0.293,
            0.117,
            0.103,
            0.315,
            0.069,
            0.418,
            0.247,
            0.483,
            0.623,
            0.562,
            1.296,
            1.337,
            0.818,
            1.491,
            1.513,
            0.945,
            1.397,
            0.759,
            0.166,
            0.178,
            0.193,
            0.085,
            0.107,
            0.078,
            0.096,
            0.129,
            0.062,
            0.149,
        ],
        [
            0.146,
            0.126,
            0.714,
            0.086,
            0.029,
            0.785,
            0.152,
            0.29,
            0.373,
            0.589,
            0.476,
            0.456,
            0.041,
            0.401,
            0.242,
            0.268,
            0.471,
            0.064,
            0.087,
            0.329,
            0.856,
            0.812,
            1.763,
            2.016,
            1.059,
            1.965,
            1.928,
            1.106,
            1.833,
            0.92,
            0.164,
            0.142,
            0.198,
            0.108,
            0.184,
            0.03,
            0.096,
            0.062,
            0.16,
            0.118,
        ],
        [
            1.811,
            1.213,
            0.844,
            1.01,
            0.954,
            1.36,
            0.333,
            0.552,
            0.471,
            0.822,
            0.365,
            0.454,
            0.076,
            0.143,
            0.293,
            0.038,
            0.265,
            0.163,
            0.176,
            0.367,
            0.154,
            0.196,
            0.107,
            0.122,
            0.108,
            0.017,
            0.19,
            0.135,
            0.091,
            0.012,
            0.892,
            0.163,
            1.04,
            0.755,
            0.197,
            0.395,
            0.681,
            0.423,
            0.893,
            0.772,
        ],
        [
            0.177,
            0.21,
            0.047,
            0.166,
            0.215,
            0.07,
            0.412,
            0.302,
            0.272,
            0.02,
            0.992,
            2.57,
            2.233,
            1.212,
            0.932,
            0.773,
            2.566,
            2.265,
            1.315,
            2.504,
            0.575,
            0.257,
            0.954,
            0.859,
            0.568,
            0.871,
            0.711,
            0.541,
            0.884,
            0.464,
            0.178,
            0.012,
            0.069,
            0.131,
            0.19,
            0.093,
            0.132,
            0.013,
            0.02,
            0.057,
        ],
        [
            0.294,
            0.297,
            0.127,
            0.379,
            0.369,
            0.024,
            0.267,
            0.138,
            0.326,
            0.312,
            0.158,
            0.675,
            0.742,
            0.439,
            0.902,
            0.422,
            1.024,
            0.396,
            0.47,
            0.947,
            0.009,
            0.134,
            0.022,
            0.175,
            0.125,
            0.094,
            0.067,
            0.02,
            0.046,
            0.03,
            0.536,
            0.273,
            0.213,
            0.23,
            0.007,
            0.238,
            0.197,
            0.083,
            0.251,
            0.1,
        ],
        [
            0.101,
            0.116,
            0.052,
            0.13,
            0.206,
            0.459,
            0.31,
            0.083,
            0.262,
            0.045,
            0.964,
            1.412,
            0.675,
            0.847,
            0.676,
            0.05,
            0.674,
            1.279,
            0.71,
            0.716,
            1.137,
            0.901,
            2.065,
            2.213,
            1.451,
            1.896,
            2.184,
            1.316,
            2.154,
            0.628,
            0.013,
            0.164,
            0.041,
            0.183,
            0.133,
            0.052,
            0.196,
            0.133,
            0.026,
            0.088,
        ],
        [
            0.371,
            0.379,
            0.041,
            0.224,
            0.32,
            0.328,
            0.471,
            0.486,
            0.422,
            0.237,
            0.047,
            0.98,
            0.676,
            0.569,
            0.589,
            0.379,
            1.035,
            1.164,
            0.469,
            1.043,
            0.175,
            0.025,
            0.11,
            0.091,
            0.005,
            0.078,
            0.166,
            0.18,
            0.188,
            0.132,
            0.93,
            0.118,
            0.841,
            1.021,
            0.195,
            0.495,
            0.46,
            0.51,
            0.888,
            0.518,
        ],
        [
            0.359,
            0.364,
            0.392,
            0.055,
            0.109,
            0.093,
            0.437,
            0.353,
            0.44,
            0.493,
            0.687,
            1.402,
            0.588,
            0.282,
            0.784,
            0.857,
            1.366,
            1.126,
            0.897,
            1.145,
            0.197,
            0.123,
            0.12,
            0.02,
            0.08,
            0.076,
            0.187,
            0.102,
            0.018,
            0.188,
            1.556,
            0.563,
            1.226,
            1.285,
            0.321,
            0.886,
            0.868,
            0.61,
            1.56,
            0.658,
        ],
    ]
)

# Omic2
omic2 = np.array(
    [
        [
            0.746,
            3.016,
            0.26,
            0.832,
            2.491,
            0.262,
            0.422,
            0.497,
            0.012,
            0.5,
            0.18,
            0.14,
            0.114,
            0.076,
            0.002,
            0.353,
            0.237,
            0.408,
            0.421,
            0.4,
        ],
        [
            0.842,
            2.054,
            0.151,
            0.442,
            1.361,
            0.288,
            0.171,
            0.458,
            0.082,
            0.31,
            0.081,
            0.307,
            0.789,
            0.553,
            0.672,
            0.055,
            0.051,
            0.007,
            0.108,
            0.103,
        ],
        [
            0.95,
            0.749,
            0.286,
            0.655,
            0.895,
            0.369,
            0.393,
            0.396,
            0.064,
            0.104,
            0.043,
            1.042,
            1.358,
            0.94,
            0.888,
            0.16,
            0.156,
            0.125,
            0.2,
            0.148,
        ],
        [
            0.278,
            0.084,
            0.259,
            0.243,
            0.379,
            0.359,
            0.107,
            0.075,
            0.172,
            0.08,
            0.364,
            1.317,
            2.067,
            1.139,
            1.094,
            0.099,
            0.033,
            0.183,
            0.073,
            0.162,
        ],
        [
            1.04,
            1.339,
            0.308,
            0.413,
            0.978,
            0.137,
            0.044,
            0.264,
            0.055,
            0.493,
            0.055,
            0.142,
            0.142,
            0.068,
            0.137,
            1.283,
            0.794,
            1.256,
            0.871,
            1.236,
        ],
        [
            0.131,
            0.047,
            0.005,
            0.421,
            0.418,
            2.599,
            1.794,
            1.684,
            0.556,
            2.24,
            0.176,
            0.638,
            1.011,
            0.446,
            0.515,
            0.197,
            0.161,
            0.098,
            0.112,
            0.161,
        ],
        [
            0.085,
            0.068,
            0.325,
            0.485,
            0.023,
            1.133,
            0.826,
            1.141,
            0.218,
            0.782,
            0.124,
            0.151,
            0.075,
            0.137,
            0.023,
            0.284,
            0.372,
            0.313,
            0.33,
            0.573,
        ],
        [
            0.24,
            0.32,
            0.254,
            0.019,
            0.019,
            1.06,
            0.857,
            1.215,
            0.189,
            0.946,
            0.37,
            1.137,
            1.957,
            1.253,
            1.071,
            0.077,
            0.094,
            0.012,
            0.019,
            0.141,
        ],
        [
            0.12,
            0.325,
            0.301,
            0.404,
            0.184,
            1.241,
            1.01,
            0.636,
            0.541,
            1.325,
            0.062,
            0.137,
            0.076,
            0.056,
            0.168,
            1.324,
            0.788,
            1.156,
            0.974,
            1.388,
        ],
        [
            0.319,
            0.11,
            0.029,
            0.461,
            0.143,
            1.101,
            0.9,
            0.426,
            0.163,
            1.066,
            0.045,
            0.192,
            0.099,
            0.036,
            0.014,
            1.81,
            1.066,
            1.693,
            1.323,
            1.855,
        ],
    ]
)

# Fix a seed
seed = 240709


def test_nmfprofiler_mu():
    model = NMFProfiler(omic1=omic1, omic2=omic2, y=y, seed=seed)
    res = model.fit()
    assert (
        np.round(res.df_errors.iloc[-1, -1], decimals=4) == 0.9604
    ), "The final loss obtained with NMFProfiler (MU version) is 0.9604."


def test_nmfprofiler_prox():
    model = NMFProfiler(
        omic1=omic1,
        omic2=omic2,
        y=y,
        seed=seed,
        as_sklearn=False,
        backtrack=True
    )
    res = model.fit()
    assert (
        res.n_iter == 6
    ), "NMFProfiler (Proximal version) needs 6 steps to converge."


def test_dir():
    assert (
        dir(NMFProfiler)[-1] == "predict"
    ), "Last method in NMFProfiler class is 'predict'"

==> nmfprofiler-0.3.0.tar.gz: nmfprofiler-0.3.0/tests/test_nmfprofiler.py <==
from nmfprofiler.nmfprofiler import NMFProfiler  # type: ignore
import numpy as np

# Generate a small example to decompose
# Groups
y = np.array([1, 1, 1, 1, 1, 0, 0, 0, 0, 0])

# Omic1
omic1 = np.array(
    [
        [
            2.278,
            3.55,
            2.38,
            2.289,
            2.3,
            2.364,
            1.562,
            1.533,
            1.434,
            2.095,
            0.427,
            0.113,
            0.278,
            0.212,
            0.306,
            0.379,
            0.375,
            0.056,
            0.219,
            0.227,
            0.148,
            0.101,
            0.166,
            0.039,
            0.046,
            0.161,
            0.163,
            0.066,
            0.012,
            0.13,
            0.169,
            0.209,
            0.207,
            0.257,
            0.078,
            0.111,
            0.064,
            0.187,
            0.159,
            0.338,
        ],
        [
            2.048,
            2.438,
            2.048,
            2.257,
            1.888,
            1.398,
            1.178,
            0.891,
            0.749,
            1.204,
            0.043,
            0.095,
            0.126,
            0.02,
            0.29,
            0.242,
            0.438,
            0.403,
            0.359,
            0.152,
            0.256,
            0.444,
            0.643,
            0.863,
            0.396,
            0.619,
            0.765,
            0.338,
            0.95,
            0.218,
            0.121,
            0.166,
            0.074,
            0.08,
            0.159,
            0.195,
            0.077,
            0.051,
            0.096,
            0.074,
        ],
        [
            1.122,
            1.31,
            1.013,
            1.645,
            0.675,
            1.187,
            0.672,
            0.894,
            0.604,
            1.362,
            0.464,
            0.109,
            0.293,
            0.117,
            0.103,
            0.315,
            0.069,
            0.418,
            0.247,
            0.483,
            0.623,
            0.562,
            1.296,
            1.337,
            0.818,
            1.491,
            1.513,
            0.945,
            1.397,
            0.759,
            0.166,
            0.178,
            0.193,
            0.085,
            0.107,
            0.078,
            0.096,
            0.129,
            0.062,
            0.149,
        ],
        [
            0.146,
            0.126,
            0.714,
            0.086,
            0.029,
            0.785,
            0.152,
            0.29,
            0.373,
            0.589,
            0.476,
            0.456,
            0.041,
            0.401,
            0.242,
            0.268,
            0.471,
            0.064,
            0.087,
            0.329,
            0.856,
            0.812,
            1.763,
            2.016,
            1.059,
            1.965,
            1.928,
            1.106,
            1.833,
            0.92,
            0.164,
            0.142,
            0.198,
            0.108,
            0.184,
            0.03,
            0.096,
            0.062,
            0.16,
            0.118,
        ],
        [
            1.811,
            1.213,
            0.844,
            1.01,
            0.954,
            1.36,
            0.333,
            0.552,
            0.471,
            0.822,
            0.365,
            0.454,
            0.076,
            0.143,
            0.293,
            0.038,
            0.265,
            0.163,
            0.176,
            0.367,
            0.154,
            0.196,
            0.107,
            0.122,
            0.108,
            0.017,
            0.19,
            0.135,
            0.091,
            0.012,
            0.892,
            0.163,
            1.04,
            0.755,
            0.197,
            0.395,
            0.681,
            0.423,
            0.893,
            0.772,
        ],
        [
            0.177,
            0.21,
            0.047,
            0.166,
            0.215,
            0.07,
            0.412,
            0.302,
            0.272,
            0.02,
            0.992,
            2.57,
            2.233,
            1.212,
            0.932,
            0.773,
            2.566,
            2.265,
            1.315,
            2.504,
            0.575,
            0.257,
            0.954,
            0.859,
            0.568,
            0.871,
            0.711,
            0.541,
            0.884,
            0.464,
            0.178,
            0.012,
            0.069,
            0.131,
            0.19,
            0.093,
            0.132,
            0.013,
            0.02,
            0.057,
        ],
        [
            0.294,
            0.297,
            0.127,
            0.379,
            0.369,
            0.024,
            0.267,
            0.138,
            0.326,
            0.312,
            0.158,
            0.675,
            0.742,
            0.439,
            0.902,
            0.422,
            1.024,
            0.396,
            0.47,
            0.947,
            0.009,
            0.134,
            0.022,
            0.175,
            0.125,
            0.094,
            0.067,
            0.02,
            0.046,
            0.03,
            0.536,
            0.273,
            0.213,
            0.23,
            0.007,
            0.238,
            0.197,
            0.083,
            0.251,
            0.1,
        ],
        [
            0.101,
            0.116,
            0.052,
            0.13,
            0.206,
            0.459,
            0.31,
            0.083,
            0.262,
            0.045,
            0.964,
            1.412,
            0.675,
            0.847,
            0.676,
            0.05,
            0.674,
            1.279,
            0.71,
            0.716,
            1.137,
            0.901,
            2.065,
            2.213,
            1.451,
            1.896,
            2.184,
            1.316,
            2.154,
            0.628,
            0.013,
            0.164,
            0.041,
            0.183,
            0.133,
            0.052,
            0.196,
            0.133,
            0.026,
            0.088,
        ],
        [
            0.371,
            0.379,
            0.041,
            0.224,
            0.32,
            0.328,
            0.471,
            0.486,
            0.422,
            0.237,
            0.047,
            0.98,
            0.676,
            0.569,
            0.589,
            0.379,
            1.035,
            1.164,
            0.469,
            1.043,
            0.175,
            0.025,
            0.11,
            0.091,
            0.005,
            0.078,
            0.166,
            0.18,
            0.188,
            0.132,
            0.93,
            0.118,
            0.841,
            1.021,
            0.195,
            0.495,
            0.46,
            0.51,
            0.888,
            0.518,
        ],
        [
            0.359,
            0.364,
            0.392,
            0.055,
            0.109,
            0.093,
            0.437,
            0.353,
            0.44,
            0.493,
            0.687,
            1.402,
            0.588,
            0.282,
            0.784,
            0.857,
            1.366,
            1.126,
            0.897,
            1.145,
            0.197,
            0.123,
            0.12,
            0.02,
            0.08,
            0.076,
            0.187,
            0.102,
            0.018,
            0.188,
            1.556,
            0.563,
            1.226,
            1.285,
            0.321,
            0.886,
            0.868,
            0.61,
            1.56,
            0.658,
        ],
    ]
)

# Omic2
omic2 = np.array(
    [
        [
            0.746,
            3.016,
            0.26,
            0.832,
            2.491,
            0.262,
            0.422,
            0.497,
            0.012,
            0.5,
            0.18,
            0.14,
            0.114,
            0.076,
            0.002,
            0.353,
            0.237,
            0.408,
            0.421,
            0.4,
        ],
        [
            0.842,
            2.054,
            0.151,
            0.442,
            1.361,
            0.288,
            0.171,
            0.458,
            0.082,
            0.31,
            0.081,
            0.307,
            0.789,
            0.553,
            0.672,
            0.055,
            0.051,
            0.007,
            0.108,
            0.103,
        ],
        [
            0.95,
            0.749,
            0.286,
            0.655,
            0.895,
            0.369,
            0.393,
            0.396,
            0.064,
            0.104,
            0.043,
            1.042,
            1.358,
            0.94,
            0.888,
            0.16,
            0.156,
            0.125,
            0.2,
            0.148,
        ],
        [
            0.278,
            0.084,
            0.259,
            0.243,
            0.379,
            0.359,
            0.107,
            0.075,
            0.172,
            0.08,
            0.364,
            1.317,
            2.067,
            1.139,
            1.094,
            0.099,
            0.033,
            0.183,
            0.073,
            0.162,
        ],
        [
            1.04,
            1.339,
            0.308,
            0.413,
            0.978,
            0.137,
            0.044,
            0.264,
            0.055,
            0.493,
            0.055,
            0.142,
            0.142,
            0.068,
            0.137,
            1.283,
            0.794,
            1.256,
            0.871,
            1.236,
        ],
        [
            0.131,
            0.047,
            0.005,
            0.421,
            0.418,
            2.599,
            1.794,
            1.684,
            0.556,
            2.24,
            0.176,
            0.638,
            1.011,
            0.446,
            0.515,
            0.197,
            0.161,
            0.098,
            0.112,
            0.161,
        ],
        [
            0.085,
            0.068,
            0.325,
            0.485,
            0.023,
            1.133,
            0.826,
            1.141,
            0.218,
            0.782,
            0.124,
            0.151,
            0.075,
            0.137,
            0.023,
            0.284,
            0.372,
            0.313,
            0.33,
            0.573,
        ],
        [
            0.24,
            0.32,
            0.254,
            0.019,
            0.019,
            1.06,
            0.857,
            1.215,
            0.189,
            0.946,
            0.37,
            1.137,
            1.957,
            1.253,
            1.071,
            0.077,
            0.094,
            0.012,
            0.019,
            0.141,
        ],
        [
            0.12,
            0.325,
            0.301,
            0.404,
            0.184,
            1.241,
            1.01,
            0.636,
            0.541,
            1.325,
            0.062,
            0.137,
            0.076,
            0.056,
            0.168,
            1.324,
            0.788,
            1.156,
            0.974,
            1.388,
        ],
        [
            0.319,
            0.11,
            0.029,
            0.461,
            0.143,
            1.101,
            0.9,
            0.426,
            0.163,
            1.066,
            0.045,
            0.192,
            0.099,
            0.036,
            0.014,
            1.81,
            1.066,
            1.693,
            1.323,
            1.855,
        ],
    ]
)

# Fix a seed
seed = 240709


def test_nmfprofiler_mu():
    model = NMFProfiler(omics=[omic1, omic2], y=y, seed=seed)
    res = model.fit()
    assert (
        np.round(res.df_errors.iloc[-1, -1], decimals=4) == 0.9604
    ), "The final loss obtained with NMFProfiler (MU version) is 0.9604."


def test_nmfprofiler_prox():
    model = NMFProfiler(
        omics=[omic1, omic2],
        y=y,
        seed=seed,
        as_sklearn=False,
        backtrack=True
    )
    res = model.fit()
    assert (
        res.n_iter == 6
    ), "NMFProfiler (Proximal version) needs 6 steps to converge."


def test_dir():
    assert (
        dir(NMFProfiler)[-1] == "predict"
    ), "Last method in NMFProfiler class is 'predict'"
